/*-
 * Copyright (c) 2012 Diane Bruce <db@FreeBSD.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer,
 *    without modification, immediately at the beginning of the file.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <sys/param.h>
#include <sys/errno.h>
#include <sys/stat.h>

#include <ctype.h>
#include <err.h>
#include <fcntl.h>
#include <grp.h>
#include <inttypes.h>
#include <libutil.h>
#include <paths.h>
#include <stdbool.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>


static void gr_print(struct group *gr);

int
main()
{
	struct group *gr;
	struct group *newgr;

	printf("Getting group wheel\n");
	gr = getgrnam("wheel");

	if (gr != NULL) 
		gr_print(gr);
	printf("Duplicating group\n");
	newgr = gr_dup(gr);
	gr_print(newgr);
	printf("Adding new user to group\n");
	newgr = gr_add(gr, "sys");
	if (newgr != NULL)
		gr_print(newgr);
}

static void
gr_print(struct group *gr)
{
	int i;

	printf("name = %s\n", gr->gr_name);
	printf("passwd = %s\n", gr->gr_passwd);
	printf("gid = %d\n", gr->gr_gid);

	if (gr->gr_mem != NULL) {
		printf("Members***\n\n");
		for (i = 0; gr->gr_mem[i] != NULL; i++)
			printf("%s\n", gr->gr_mem[i]);
	}
}
